@@ -236,77 +236,103 @@ bool qpwgraph_patchbay::scan (void)
 	if (scene == nullptr)
 		return false;
 
-	QHash<Item, qpwgraph_connect *> connects;
+	QHash<Item, qpwgraph_connect *> disconnects;
 
 	Items::ConstIterator iter = m_items.constBegin();
 	const Items::ConstIterator& iter_end = m_items.constEnd();
 	for ( ; iter != iter_end; ++iter) {
 		Item *item = iter.value();
-		qpwgraph_node *node1
-			= m_canvas->findNode(
+		QList<qpwgraph_node *> nodes1
+			= m_canvas->findNodes(
 				item->node1,
 				qpwgraph_item::Output,
 				item->node_type);
-		if (node1 == nullptr)
-			node1 = m_canvas->findNode(
+		if (nodes1.isEmpty())
+			nodes1 = m_canvas->findNodes(
 				item->node1,
 				qpwgraph_item::Duplex,
 				item->node_type);
-		if (node1 == nullptr)
+		if (nodes1.isEmpty())
 			continue;
-		qpwgraph_port *port1
-			= node1->findPort(
-				item->port1,
-				qpwgraph_item::Output,
-				item->port_type);
-		if (port1 == nullptr)
-			continue;
-		qpwgraph_node * node2
-			= m_canvas->findNode(
-				item->node2,
-				qpwgraph_item::Input,
-				item->node_type);
-		if (node2 == nullptr)
-			node2 = m_canvas->findNode(
-				item->node2,
-				qpwgraph_item::Duplex,
-				item->node_type);
-		if (node2 == nullptr)
-			continue;
-		qpwgraph_port * port2
-			= node2->findPort(
-				item->port2,
-				qpwgraph_item::Input,
-				item->port_type);
-		if (port2 == nullptr)
-			continue;
-		if (m_exclusive) {
-			foreach (qpwgraph_connect *connect, port1->connects()) {
-				qpwgraph_port *port3 = connect->port2();
-				if (port3 == nullptr)
+		foreach (qpwgraph_node *node1, nodes1) {
+			qpwgraph_port *port1
+				= node1->findPort(
+					item->port1,
+					qpwgraph_item::Output,
+					item->port_type);
+			if (port1 == nullptr)
+				continue;
+			QList<qpwgraph_node *> nodes2
+				= m_canvas->findNodes(
+					item->node2,
+					qpwgraph_item::Input,
+					item->node_type);
+			if (nodes2.isEmpty())
+				nodes2 = m_canvas->findNodes(
+					item->node2,
+					qpwgraph_item::Duplex,
+					item->node_type);
+			if (nodes2.isEmpty())
+				continue;
+			foreach (qpwgraph_node *node2, nodes2) {
+				qpwgraph_port *port2
+					= node2->findPort(
+						item->port2,
+						qpwgraph_item::Input,
+						item->port_type);
+				if (port2 == nullptr)
 					continue;
-				if (port3 != port2) {
-					qpwgraph_node *node3 = port3->portNode();
-					if (node3 == nullptr)
-						continue;
-					const Item item2(
-						node1->nodeType(),
-						port1->portType(),
-						node1->nodeName(),
-						port1->portName(),
-						node3->nodeName(),
-						port3->portName());
-					if (m_items.constFind(item2) == iter_end)
-						connects.insert(item2, connect);
+				if (m_exclusive) {
+					foreach (qpwgraph_connect *connect12, port1->connects()) {
+						qpwgraph_port *port12 = connect12->port2();
+						if (port12 == nullptr)
+							continue;
+						if (port12 != port2) {
+							qpwgraph_node *node12 = port12->portNode();
+							if (node12 == nullptr)
+								continue;
+							const Item item12(
+								node1->nodeType(),
+								port1->portType(),
+								node1->nodeName(),
+								port1->portName(),
+								node12->nodeName(),
+								port12->portName());
+							if (m_items.constFind(item12) == iter_end)
+								disconnects.insert(item12, connect12);
+						}
+					}
+					foreach (qpwgraph_connect *connect21, port2->connects()) {
+						qpwgraph_port *port21 = connect21->port1();
+						if (port21 == nullptr)
+							continue;
+						if (port21 != port1) {
+							qpwgraph_node *node21 = port21->portNode();
+							if (node21 == nullptr)
+								continue;
+							const Item item21(
+								node21->nodeType(),
+								port21->portType(),
+								node21->nodeName(),
+								port21->portName(),
+								node2->nodeName(),
+								port2->portName());
+							if (m_items.constFind(item21) == iter_end) {
+								disconnects.insert(item21, connect21);
+							}
+						}
+					}
 				}
+				if (!port1->findConnect(port2))
+					m_canvas->emitConnected(port1, port2);
 			}
 		}
-		if (!port1->findConnect(port2))
-			m_canvas->emitConnected(port1, port2);
 	}
 
-	QHash<Item, qpwgraph_connect *>::ConstIterator iter2 = connects.constBegin();
-	const QHash<Item, qpwgraph_connect *>::ConstIterator& iter2_end = connects.constEnd();
+	QHash<Item, qpwgraph_connect *>::ConstIterator iter2
+		= disconnects.constBegin();
+	const QHash<Item, qpwgraph_connect *>::ConstIterator& iter2_end
+		= disconnects.constEnd();
 	for (; iter2 != iter2_end; ++iter2) {
 		qpwgraph_connect *connect = iter2.value();
 		if (connect)
