@@ -964,6 +964,9 @@ bool qpwgraph_pipewire::findNodePort (
 		}
 	}
 
+	if (*node && m_recycled.value(qpwgraph_node::NodeIdKey(*node), nullptr))
+		return false;
+
 	if (*node && n->node_changed) {
 		canvas()->releaseNode(*node);
 		*node = nullptr;
@@ -1043,10 +1046,11 @@ void qpwgraph_pipewire::updateItems (void)
 					port_mode1, &node1, &port1, true)) {
 				node1->setMarked(true);
 				port1->setMarked(true);
+				if ((port_mode1 & qpwgraph_item::Output)
+					&& (!p1->port_links.isEmpty())) {
+					ports.append(port1);
+				}
 			}
-			if ((port_mode1 & qpwgraph_item::Output)
-				&& (!p1->port_links.isEmpty()))
-				ports.append(port1);
 		}
 	}
 
@@ -1084,6 +1088,8 @@ void qpwgraph_pipewire::updateItems (void)
 	// 3. Clean-up all un-marked items...
 	//
 	qpwgraph_sect::resetItems(qpwgraph_pipewire::nodeType());
+
+	m_recycled.clear();
 }
 
 
@@ -1100,6 +1106,8 @@ void qpwgraph_pipewire::clearItems (void)
 	// Clean-up all items...
 	//
 	qpwgraph_sect::clearItems(qpwgraph_pipewire::nodeType());
+
+	m_recycled.clear();
 }
 
 
@@ -1219,6 +1227,8 @@ qpwgraph_pipewire::Node *qpwgraph_pipewire::createNode (
 	qpwgraph_item::Mode node_mode,
 	uint node_type )
 {
+	recycleNode(node_id, node_mode);
+
 	Node *node = new Node(node_id);
 	node->node_name = node_name;
 	node->node_mode = node_mode;
@@ -1363,4 +1373,28 @@ void qpwgraph_pipewire::destroyLink ( Link *link )
 }
 
 
+// Special node recycler...
+void qpwgraph_pipewire::recycleNode (
+	uint node_id, qpwgraph_item::Mode node_mode )
+{
+	const uint node_type = qpwgraph_pipewire::nodeType();
+	qpwgraph_node *node = qpwgraph_sect::findNode(node_id, node_mode, node_type);
+	if (node == nullptr)
+		node = qpwgraph_sect::findNode(node_id, qpwgraph_item::Duplex, node_type);
+	if (node) {
+		m_recycled.insert(qpwgraph_node::NodeIdKey(node), node);
+	#if 0
+		for (qpwgraph_port *port : node->ports()) {
+			if (port->portMode() & qpwgraph_item::Output) {
+				for (qpwgraph_connect *connect : port->connects()) {
+					connect->setMarked(false);
+					connect->disconnect();
+				}
+			}
+		}
+	#endif
+	}
+}
+
+
 // end of qpwgraph_pipewire.cpp
